function S = times(A,B)

% S = TIMES(A,B)     
%
% Element-wise multiply of two timescale objects to produce another. Works
% if either argument is a scalar also.
%
% INPUTS:
% A,B       Timescale objects to multiply.
%
%       
% OUTPUTS: 
% S         Timescale object holding the product.
%

% Ian Gravagne, 12/29/03 Baylor University

if( (~isa(A,'timescale') & ~isnumeric(A)) | (~isa(B,'timescale') & ~isnumeric(B)) )
    error('Only accepts timescale objects and scalars as inputs.');
end

S = timescale;

if(isa(A,'timescale') & isa(B,'timescale'))
    if(incompatible(A,B))
        error('Timescale objects have different length or types of data (continuous or discrete).')
    end
    S.type = A.type;
    S.data = A.data .* B.data;
elseif(isa(A,'timescale'))
    S.type = A.type;
    S.data = A.data .* B(1);
elseif(isa(B,'timescale'))
    S.type = B.type;
    S.data = A(1) .* B.data;
end
